@@ -1,9 +1,8 @@
 import sys
 import time
 
-from celery.exceptions import TaskRevokedError
-
 import dagster._check as check
+from celery.exceptions import TaskRevokedError
 from dagster._core.errors import DagsterSubprocessError
 from dagster._core.events import DagsterEvent, EngineEventData
 from dagster._core.execution.context.system import PlanOrchestrationContext
@@ -25,7 +24,6 @@ DELEGATE_MARKER = "celery_queue_wait"
 
 
 def core_celery_execution_loop(pipeline_context, execution_plan, step_execution_fn):
-
     check.inst_param(pipeline_context, "pipeline_context", PlanOrchestrationContext)
     check.inst_param(execution_plan, "execution_plan", ExecutionPlan)
     check.callable_param(step_execution_fn, "step_execution_fn")
@@ -37,8 +35,10 @@ def core_celery_execution_loop(pipeline_context, execution_plan, step_execution_
         # https://github.com/dagster-io/dagster/issues/2440
         check.invariant(
             execution_plan.artifacts_persisted,
-            "Cannot use in-memory storage with Celery, use filesystem (on top of NFS or "
-            "similar system that allows files to be available to all nodes), S3, or GCS",
+            (
+                "Cannot use in-memory storage with Celery, use filesystem (on top of NFS or "
+                "similar system that allows files to be available to all nodes), S3, or GCS"
+            ),
         )
 
     app = make_app(executor.app_args())
@@ -59,14 +59,16 @@ def core_celery_execution_loop(pipeline_context, execution_plan, step_execution_
         retry_mode=pipeline_context.executor.retries,
         sort_key_fn=priority_for_step,
     ) as active_execution:
-
         stopping = False
 
         while (not active_execution.is_complete and not stopping) or step_results:
             if active_execution.check_for_interrupts():
                 yield DagsterEvent.engine_event(
                     pipeline_context,
-                    "Celery executor: received termination signal - revoking active tasks from workers",
+                    (
+                        "Celery executor: received termination signal - revoking active tasks from"
+                        " workers"
+                    ),
                     EngineEventData.interrupted(list(step_results.keys())),
                 )
                 stopping = True
