@@ -1,6 +1,13 @@
-from dagster import Executor, Field, Noneable, Permissive, StringSource
-from dagster import _check as check
-from dagster import executor, multiple_process_executor_requirements
+from dagster import (
+    Executor,
+    Field,
+    Noneable,
+    Permissive,
+    StringSource,
+    _check as check,
+    executor,
+    multiple_process_executor_requirements,
+)
 from dagster._core.execution.retries import RetryMode, get_retries_config
 from dagster._grpc.types import ExecuteStepArgs
 from dagster._serdes import pack_value
@@ -88,7 +95,6 @@ def celery_executor(init_context):
     different broker than the one your workers are listening to, the workers will never be able to
     pick up tasks for execution.
     """
-
     return CeleryExecutor(
         broker=init_context.executor_config.get("broker"),
         backend=init_context.executor_config.get("backend"),
